@@ -34,7 +34,6 @@ from spyder.api.translations import get_translation
 from spyder.api.widgets.main_widget import PluginMainWidget
 from spyder.config.base import get_conf_path
 from spyder.plugins.variableexplorer.widgets.texteditor import TextEditor
-from spyder.plugins.run.widgets import get_run_configuration
 from spyder.utils import programs
 from spyder.utils.misc import getcwd_or_home
 from spyder.utils.palette import SpyderPalette
@@ -337,20 +336,6 @@ class SpyderLineProfilerWidget(PluginMainWidget):
 
         if self.filecombo.is_valid():
             filename = str(self.filecombo.currentText())
-            runconf = get_run_configuration(filename)
-            if runconf is not None:
-                if wdir is None:
-                    if runconf.wdir_enabled:
-                        wdir = runconf.wdir
-                    elif runconf.cw_dir:
-                        wdir = os.getcwd()
-                    elif runconf.file_dir:
-                        wdir = osp.dirname(filename)
-                    elif runconf.fixed_dir:
-                        wdir = runconf.dir
-                if args is None:
-                    if runconf.args_enabled:
-                        args = runconf.args
             if wdir is None:
                 wdir = osp.dirname(filename)
             self.start(wdir, args)
@@ -431,7 +416,11 @@ class SpyderLineProfilerWidget(PluginMainWidget):
         self.clear_data()
         self.error_output = ''
 
-        p_args = ['-m', 'kernprof', '-lvb', '-o', self.DATAPATH]
+        # Use UTF-8 mode so that profiler writes its output to DATAPATH using
+        # UTF-8 encoding, instead of the ANSI code page on Windows.
+        # See issue spyder-ide/spyder-line-profiler#90
+        p_args = ['-X', 'utf8', '-m', 'kernprof', '-lvb', '-o', self.DATAPATH]
+
         if os.name == 'nt':
             # On Windows, one has to replace backslashes by slashes to avoid
             # confusion with escape characters (otherwise, for example, '\t'
